from ..constants import AuthenticationScheme
from .authentication import Authentication


class ExternalAuthentication(Authentication):
    """External authentication representation."""

    def __init__(
        self,
        token: str = None,
        issuer: str = None,
        **kwargs
    ) -> None:
        super().__init__(AuthenticationScheme.EXTERNAL, **kwargs)
        self.token = token
        self.issuer = issuer



from typing import Any
from .envelope import Envelope


class Message(Envelope):
    """Message representation."""

    def __init__(
        self,
        type_n: str = None,
        content: Any = None,
        **kwargs
    ) -> None:
        super().__init__(**kwargs)
        self.type_n = type_n
        self.content = content



from ..serializable import Serializable


class Authentication(Serializable):
    """Authentication scheme."""

    def __init__(self, scheme: str = None, **kwargs) -> None:
        self.scheme = scheme



from .envelope import Envelope
from .reason import Reason


class Notification(Envelope):
    """Notification representation."""

    def __init__(
        self,
        event: str = None,
        reason: Reason = None,
        **kwargs
    ) -> None:
        super().__init__(**kwargs)
        self.event = event
        self.reason = reason
